@@ -115,6 +115,17 @@ describe 'tempest' do
       end
     end
 
+    context 'with tempest_roles' do
+      let :params do
+        { :configure_images => false,
+          :tempest_roles    => ['Member', 'creator'], }
+      end
+
+      it 'properly sets  tempest_roles in tempest.conf' do
+        is_expected.to contain_tempest_config('auth/tempest_roles').with_value('Member,creator')
+      end
+    end
+
     context 'with parameters' do
       let :params do
         { :configure_images    => true,
@@ -174,6 +185,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('auth/admin_password').with_secret( true )
           is_expected.to contain_tempest_config('auth/admin_project_name').with(:value => nil)
           is_expected.to contain_tempest_config('auth/admin_username').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/tempest_roles').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => nil)
           is_expected.to contain_tempest_config('dns/nameservers').with(:value => nil)
           is_expected.to contain_tempest_config('compute/change_password_available').with(:value => nil)
@@ -185,6 +197,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('compute/image_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('compute/resize_available').with(:value => nil)
           is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
+          is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => false)
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
           is_expected.to contain_tempest_config('identity/auth_version').with(:value => 'v2')
           is_expected.to contain_tempest_config('identity/alt_password').with(:value => nil)
@@ -205,14 +218,17 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('network/public_router_id').with(:value => '')
           is_expected.to contain_tempest_config('dashboard/login_url').with(:value => nil)
           is_expected.to contain_tempest_config('dashboard/dashboard_url').with(:value => nil)
+          is_expected.to contain_tempest_config('database/db_flavor_ref').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('service_available/cinder').with(:value => true)
           is_expected.to contain_tempest_config('service_available/glance').with(:value => true)
           is_expected.to contain_tempest_config('service_available/heat').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ceilometer').with(:value => false)
           is_expected.to contain_tempest_config('service_available/aodh').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/aodh_plugin').with(:value => false)
           is_expected.to contain_tempest_config('service_available/gnocchi').with(:value => false)
           is_expected.to contain_tempest_config('service_available/horizon').with(:value => true)
           is_expected.to contain_tempest_config('service_available/neutron').with(:value => true)
+          is_expected.to contain_tempest_config('service_available/mistral').with(:value => false)
           is_expected.to contain_tempest_config('service_available/nova').with(:value => true)
           is_expected.to contain_tempest_config('service_available/sahara').with(:value => false)
           is_expected.to contain_tempest_config('service_available/murano').with(:value => false)
@@ -220,6 +236,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/trove').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ironic').with(:value => false)
           is_expected.to contain_tempest_config('service_available/zaqar').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/ec2api').with(:value => false)
           is_expected.to contain_tempest_config('service_available/designate').with(:value => false)
           is_expected.to contain_tempest_config('whitebox/db_uri').with(:value => nil)
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
@@ -307,6 +324,7 @@ describe 'tempest' do
         it { expect { is_expected.to contain_package('python-neutron-fwaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-lbaas-tests') } }
         it { expect { is_expected.to contain_package('python-neutron-vpnaas-tests') } }
+        it { expect { is_expected.to contain_package('python-horizon-tests') } }
       end
     end
   end
